import request from '@/utils/request'

//查询地区
export function getarealist(params) {
    return request({
        url: '/system/manage/area/list',
        method: 'get',
        params
    })
}

//查询地区子级数据
export function getareaLevellist(params) {
    return request({
        url: '/system/manage/area/get-level-list',
        method: 'get',
        params
    })
}

//删除行政区划
export function deletManageArea(pkId) {
    return request({
        url: '/system/manage/area/' + pkId,
        method: 'delete',
    })
}

//新增行政区划
export function saveArea(data) {
    return request({
        url: '/system/manage/area/save',
        method: 'post',
        data
    })
}

//修改行政区划
export function updateArea(data) {
    return request({
        url: '/system/manage/area/update',
        method: 'post',
        data
    })
}

//查看单条行政区划
export function getareaDetailList(params) {
    return request({
        url: '/system/manage/area/detail',
        method: 'get',
        params
    })
}
